# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: diagnostic.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'diagnostic.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import device_info_pb2 as device__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x64iagnostic.proto\x12\ndiagnostic\x1a\x11\x64\x65vice_info.proto\"\x93\x04\n\x08\x43ounters\x12\'\n\x1fhawkbit_status_connection_error\x18\x01 \x01(\r\x12,\n hawkbit_status_unconfirmed_image\x18\x02 \x01(\rB\x02\x18\x01\x12)\n\x1dhawkbit_status_metadata_error\x18\x03 \x01(\rB\x02\x18\x01\x12%\n\x1dhawkbit_status_download_error\x18\x04 \x01(\r\x12*\n\x1ehawkbit_status_already_updated\x18\x05 \x01(\rB\x02\x18\x01\x12(\n hawkbit_status_update_downloaded\x18\x06 \x01(\r\x12 \n\x18hawkbit_status_no_update\x18\x07 \x01(\r\x12(\n\x1chawkbit_status_cancel_update\x18\x08 \x01(\rB\x02\x18\x01\x12,\n hawkbit_status_probe_in_progress\x18\t \x01(\rB\x02\x18\x01\x12$\n\x1ctimeout_internet_unreachable\x18\n \x01(\r\x12\"\n\x1atimeout_hawkbit_connection\x18\x0b \x01(\r\x12#\n\x1bhan_msg_successfully_parsed\x18\x0c \x01(\r\x12\x1f\n\x17han_msg_buffer_overflow\x18\r \x01(\r\"\xb0\x01\n\nDiagnostic\x12#\n\x04type\x18\x01 \x01(\x0e\x32\x15.diagnostic.EventType\x12\x10\n\x08uptime_s\x18\x02 \x01(\x04\x12\x15\n\rwifi_rssi_dbm\x18\x03 \x01(\x05\x12,\n\x0b\x64\x65vice_info\x18\x04 \x01(\x0b\x32\x17.device_info.DeviceInfo\x12&\n\x08\x63ounters\x18\x05 \x01(\x0b\x32\x14.diagnostic.Counters*\x9b\x02\n\tEventType\x12\x1a\n\x16\x45VENT_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10\x45VENT_TYPE_TIMER\x10\x01\x12%\n!EVENT_TYPE_PROVISIONING_REQUESTED\x10\x02\x12\x1d\n\x19\x45VENT_TYPE_MQTT_CONNECTED\x10\x03\x12\x1f\n\x1b\x45VENT_TYPE_REBOOT_REQUESTED\x10\x04\x12\x1b\n\x17\x45VENT_TYPE_BOOT_UNKNOWN\x10\x05\x12\x1c\n\x18\x45VENT_TYPE_BOOT_SOFTWARE\x10\x06\x12\x1c\n\x18\x45VENT_TYPE_BOOT_POWER_ON\x10\x07\x12\x1c\n\x18\x45VENT_TYPE_BOOT_WATCHDOG\x10\x08\x42;\n7io.bitvis.power.interfaces.powerhub.diagnostic.protobufP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'diagnostic_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n7io.bitvis.power.interfaces.powerhub.diagnostic.protobufP\001'
  _globals['_COUNTERS'].fields_by_name['hawkbit_status_unconfirmed_image']._loaded_options = None
  _globals['_COUNTERS'].fields_by_name['hawkbit_status_unconfirmed_image']._serialized_options = b'\030\001'
  _globals['_COUNTERS'].fields_by_name['hawkbit_status_metadata_error']._loaded_options = None
  _globals['_COUNTERS'].fields_by_name['hawkbit_status_metadata_error']._serialized_options = b'\030\001'
  _globals['_COUNTERS'].fields_by_name['hawkbit_status_already_updated']._loaded_options = None
  _globals['_COUNTERS'].fields_by_name['hawkbit_status_already_updated']._serialized_options = b'\030\001'
  _globals['_COUNTERS'].fields_by_name['hawkbit_status_cancel_update']._loaded_options = None
  _globals['_COUNTERS'].fields_by_name['hawkbit_status_cancel_update']._serialized_options = b'\030\001'
  _globals['_COUNTERS'].fields_by_name['hawkbit_status_probe_in_progress']._loaded_options = None
  _globals['_COUNTERS'].fields_by_name['hawkbit_status_probe_in_progress']._serialized_options = b'\030\001'
  _globals['_EVENTTYPE']._serialized_start=765
  _globals['_EVENTTYPE']._serialized_end=1048
  _globals['_COUNTERS']._serialized_start=52
  _globals['_COUNTERS']._serialized_end=583
  _globals['_DIAGNOSTIC']._serialized_start=586
  _globals['_DIAGNOSTIC']._serialized_end=762
# @@protoc_insertion_point(module_scope)
