# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: han_port.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'han_port.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0ehan_port.proto\x12\x08han_port\"\x87\x13\n\rHanPortSample\x12\"\n\x15timestamp_utc_meter_s\x18\x01 \x01(\x04H\x00\x88\x01\x01\x12 \n\x13timestamp_utc_ntp_s\x18\x1c \x01(\x04H\x01\x88\x01\x01\x12\x32\n%energy_active_delivered_to_client_kwh\x18\x02 \x01(\x02H\x02\x88\x01\x01\x12\x32\n%energy_active_delivered_by_client_kwh\x18\x03 \x01(\x02H\x03\x88\x01\x01\x12\x36\n)energy_reactive_delivered_to_client_kvarh\x18\x04 \x01(\x02H\x04\x88\x01\x01\x12\x36\n)energy_reactive_delivered_by_client_kvarh\x18\x05 \x01(\x02H\x05\x88\x01\x01\x12\x30\n#power_active_delivered_to_client_kw\x18\x06 \x01(\x02H\x06\x88\x01\x01\x12\x30\n#power_active_delivered_by_client_kw\x18\x07 \x01(\x02H\x07\x88\x01\x01\x12\x34\n\'power_reactive_delivered_to_client_kvar\x18\x08 \x01(\x02H\x08\x88\x01\x01\x12\x34\n\'power_reactive_delivered_by_client_kvar\x18\t \x01(\x02H\t\x88\x01\x01\x12\x33\n&power_active_l1_delivered_to_client_kw\x18\n \x01(\x02H\n\x88\x01\x01\x12\x33\n&power_active_l1_delivered_by_client_kw\x18\x0b \x01(\x02H\x0b\x88\x01\x01\x12\x33\n&power_active_l2_delivered_to_client_kw\x18\x0c \x01(\x02H\x0c\x88\x01\x01\x12\x33\n&power_active_l2_delivered_by_client_kw\x18\r \x01(\x02H\r\x88\x01\x01\x12\x33\n&power_active_l3_delivered_to_client_kw\x18\x0e \x01(\x02H\x0e\x88\x01\x01\x12\x33\n&power_active_l3_delivered_by_client_kw\x18\x0f \x01(\x02H\x0f\x88\x01\x01\x12\x37\n*power_reactive_l1_delivered_to_client_kvar\x18\x10 \x01(\x02H\x10\x88\x01\x01\x12\x37\n*power_reactive_l1_delivered_by_client_kvar\x18\x11 \x01(\x02H\x11\x88\x01\x01\x12\x37\n*power_reactive_l2_delivered_to_client_kvar\x18\x12 \x01(\x02H\x12\x88\x01\x01\x12\x37\n*power_reactive_l2_delivered_by_client_kvar\x18\x13 \x01(\x02H\x13\x88\x01\x01\x12\x37\n*power_reactive_l3_delivered_to_client_kvar\x18\x14 \x01(\x02H\x14\x88\x01\x01\x12\x37\n*power_reactive_l3_delivered_by_client_kvar\x18\x15 \x01(\x02H\x15\x88\x01\x01\x12\x1f\n\x12phase_voltage_l1_v\x18\x16 \x01(\x02H\x16\x88\x01\x01\x12\x1f\n\x12phase_voltage_l2_v\x18\x17 \x01(\x02H\x17\x88\x01\x01\x12\x1f\n\x12phase_voltage_l3_v\x18\x18 \x01(\x02H\x18\x88\x01\x01\x12\x1f\n\x12phase_current_l1_a\x18\x19 \x01(\x02H\x19\x88\x01\x01\x12\x1f\n\x12phase_current_l2_a\x18\x1a \x01(\x02H\x1a\x88\x01\x01\x12\x1f\n\x12phase_current_l3_a\x18\x1b \x01(\x02H\x1b\x88\x01\x01\x42\x18\n\x16_timestamp_utc_meter_sB\x16\n\x14_timestamp_utc_ntp_sB(\n&_energy_active_delivered_to_client_kwhB(\n&_energy_active_delivered_by_client_kwhB,\n*_energy_reactive_delivered_to_client_kvarhB,\n*_energy_reactive_delivered_by_client_kvarhB&\n$_power_active_delivered_to_client_kwB&\n$_power_active_delivered_by_client_kwB*\n(_power_reactive_delivered_to_client_kvarB*\n(_power_reactive_delivered_by_client_kvarB)\n\'_power_active_l1_delivered_to_client_kwB)\n\'_power_active_l1_delivered_by_client_kwB)\n\'_power_active_l2_delivered_to_client_kwB)\n\'_power_active_l2_delivered_by_client_kwB)\n\'_power_active_l3_delivered_to_client_kwB)\n\'_power_active_l3_delivered_by_client_kwB-\n+_power_reactive_l1_delivered_to_client_kvarB-\n+_power_reactive_l1_delivered_by_client_kvarB-\n+_power_reactive_l2_delivered_to_client_kvarB-\n+_power_reactive_l2_delivered_by_client_kvarB-\n+_power_reactive_l3_delivered_to_client_kvarB-\n+_power_reactive_l3_delivered_by_client_kvarB\x15\n\x13_phase_voltage_l1_vB\x15\n\x13_phase_voltage_l2_vB\x15\n\x13_phase_voltage_l3_vB\x15\n\x13_phase_current_l1_aB\x15\n\x13_phase_current_l2_aB\x15\n\x13_phase_current_l3_ab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'han_port_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_HANPORTSAMPLE']._serialized_start=29
  _globals['_HANPORTSAMPLE']._serialized_end=2468
# @@protoc_insertion_point(module_scope)
