# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device_info.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'device_info.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x64\x65vice_info.proto\x12\x0b\x64\x65vice_info\"^\n\nDeviceInfo\x12\x13\n\x0bmac_address\x18\x01 \x01(\x0c\x12\x12\n\nmodel_name\x18\x02 \x01(\t\x12\x12\n\nsw_version\x18\x03 \x01(\t\x12\x13\n\x0bhw_revision\x18\x04 \x01(\rB;\n7io.bitvis.power.interfaces.powerhub.deviceinfo.protobufP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device_info_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n7io.bitvis.power.interfaces.powerhub.deviceinfo.protobufP\001'
  _globals['_DEVICEINFO']._serialized_start=34
  _globals['_DEVICEINFO']._serialized_end=128
# @@protoc_insertion_point(module_scope)
