# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: powerhub.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'powerhub.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import han_port_pb2 as han__port__pb2
from . import device_info_pb2 as device__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0epowerhub.proto\x12\x08powerhub\x1a\x0ehan_port.proto\x1a\x11\x64\x65vice_info.proto\"\xcc\x01\n\nDiagnostic\x12!\n\x04type\x18\x01 \x01(\x0e\x32\x13.powerhub.EventType\x12\x10\n\x08uptime_s\x18\x02 \x01(\x04\x12\x15\n\rwifi_rssi_dbm\x18\x03 \x01(\x05\x12,\n\x0b\x64\x65vice_info\x18\x04 \x01(\x0b\x32\x17.device_info.DeviceInfo\x12#\n\x1bhan_msg_successfully_parsed\x18\x05 \x01(\r\x12\x1f\n\x17han_msg_buffer_overflow\x18\x06 \x01(\r\"k\n\x07Payload\x12)\n\x06sample\x18\x01 \x01(\x0b\x32\x17.han_port.HanPortSampleH\x00\x12*\n\ndiagnostic\x18\x02 \x01(\x0b\x32\x14.powerhub.DiagnosticH\x00\x42\t\n\x07payload*\x9b\x02\n\tEventType\x12\x1a\n\x16\x45VENT_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10\x45VENT_TYPE_TIMER\x10\x01\x12%\n!EVENT_TYPE_PROVISIONING_REQUESTED\x10\x02\x12\x1d\n\x19\x45VENT_TYPE_MQTT_CONNECTED\x10\x03\x12\x1f\n\x1b\x45VENT_TYPE_REBOOT_REQUESTED\x10\x04\x12\x1b\n\x17\x45VENT_TYPE_BOOT_UNKNOWN\x10\x05\x12\x1c\n\x18\x45VENT_TYPE_BOOT_SOFTWARE\x10\x06\x12\x1c\n\x18\x45VENT_TYPE_BOOT_POWER_ON\x10\x07\x12\x1c\n\x18\x45VENT_TYPE_BOOT_WATCHDOG\x10\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'powerhub_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_EVENTTYPE']._serialized_start=380
  _globals['_EVENTTYPE']._serialized_end=663
  _globals['_DIAGNOSTIC']._serialized_start=64
  _globals['_DIAGNOSTIC']._serialized_end=268
  _globals['_PAYLOAD']._serialized_start=270
  _globals['_PAYLOAD']._serialized_end=377
# @@protoc_insertion_point(module_scope)
